# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['bib2yaml']

package_data = \
{'': ['*']}

install_requires = \
['argparse>=1.4.0,<2.0.0',
 'bibtexparser>=1.4.0,<2.0.0',
 'pylatexenc>=2.10,<3.0']

setup_kwargs = {
    'name': 'bib2yaml',
    'version': '1.0.0',
    'description': 'Converts a BibTeX file to YAML format',
    'long_description': "### Converts a BibTeX file to YAML format\n\nBIB2YAML is a lightweight Python package that provides an easy and efficient way to convert BibTeX (.bib) files to YAML (.yaml) format.\n\n### Usage\n\n```python\n\n    # interactive\n    # path to the bib file\n    bib = '/Users/aj/Downloads/ref.bib'\n    # path to the output directory\n    outputDir = '/Users/aj/Downloads/'\n    \n    # Run the function\n    bib2yaml (bib, outputDir, fileName='ref')\n    \n    # commandline\n    python bib2yaml.py --bib /Users/aj/Downloads/ref.bib --outputDir /Users/aj/Downloads/\n    \n\n```",
    'author': 'Ajit Johnson Nirmal',
    'author_email': 'ajitjohnson.n@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Feb 19 20:58:50 2023
@author: Ajit Johnson Nirmal
Converts a BibTeX file to YAML format.
"""

# Libs
import bibtexparser
from pylatexenc.latex2text import LatexNodes2Text
import yaml
import argparse


# function
def bib2yaml (bib, outputDir, fileName='ref'):
    
    """
    Parameters
    ----------
    bib (str): The path to the BibTeX file to be converted.
    outputDir (str): The path where the YAML file will be saved.
    fileName (str): The name of the output file, without extension. Default is 'ref'.

    Returns
    -------
    None.
    
    Example
    -------
    ```python
    # interactive
    bib = '/Users/aj/Downloads/ref.bib'
    outputDir = '/Users/aj/Downloads/'
    bib2yaml (bib, outputDir, fileName='ref')
    
    # commandline
    python bib2yaml.py --bib /Users/aj/Downloads/ref.bib --outputDir /Users/aj/Downloads/
    
    ```

    """
    
    # resolve output path
    outputFile = outputDir + '/' + fileName + '.yml'
    lt = LatexNodes2Text()
    
    with open(bib) as f:
        db = bibtexparser.load(f)
    for e in db.entries:
        for k, v in e.items():
            e[k] = lt.latex_to_text(v)
            
    with open(outputFile, 'w') as f:
        yaml.dump(db.entries, f, allow_unicode=True)

    
    
if __name__ == '__main__':
    parser = argparse.ArgumentParser(description='Convert a BibTeX file to YAML format.')
    parser.add_argument('--bib', type=str, help='path to the BibTeX file to be converted')
    parser.add_argument('--outputDir', type=str, help='path where the YAML file will be saved')
    parser.add_argument('--fileName', type=str, default='ref', help='name of the output file, without extension (default: ref)')
    
    args = parser.parse_args()
    bib2yaml(bib=args.bib, 
             outputDir=args.outputDir, 
             fileName=args.fileName)


